/*
 *   Citybuilding Mappers - create minimaps from citybuilding game files
 *   Copyright (C) 2007, 2008  Bianca van Schaik
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef CAESAR3FILE_H
#define CAESAR3FILE_H

#include "gamefile.h"
#include "caesar3colours.h"
#include <QString>

class IndexedImage;

/**
* Walker - stores just the information from the walker table inside
* the saved games to draw the walkers on the minimap.
*/
typedef struct {
	unsigned short type;
	unsigned char x;
	unsigned char y;
} Walker;

/**
* Loads a Caesar 3 .sav or .map file and extracts the minimap.
*/
class Caesar3File : public GameFile {
	public:
		/**
		* Constructor. Opens `filename' for parsing. `filename' should exist
		* @param filename Name of the file to open
		*/
		Caesar3File(const QString &filename);
		
		/**
		* Parses the file and returns the minimap image as PNG image
		* Ownership of the image passes to the caller
		*/
		IndexedImage *getImage();
		
	private:
		void getBuildingColours(quint16 building, quint8 edge,
			quint8 edge_right, quint8 edge_below, int *c1, int *c2);
		void getTerrainColours(quint16 terrain, quint8 random, int *c1, int *c2);
		Grid<quint8> *getRandomData();
		Walker *getWalkers();
		void getMapsizeAndClimate(int *mapsize, char *climate);
		
		Caesar3Colours *colours;
};

#endif /* CAESAR3FILE_H */
