/*
 *   Citybuilding Mappers - create minimaps from citybuilding game files
 *   Copyright (C) 2007, 2008  Bianca van Schaik
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef EMPERORFILE_H
#define EMPERORFILE_H

#include <QString>

#include "gamefile.h"
#include "grid.h"
#include "emperorcolours.h"

class IndexedImage;

typedef struct {
	quint16 type;
	quint16 x;
	quint16 y;
} Walker;

typedef struct {
	quint16 type;
	quint8 alive;
	quint16 x;
	quint16 y;
	quint8 size;
	quint8 rotation;
	int colorid;
} Building;

class EmperorFile : public GameFile {
	public:
		EmperorFile(const QString &filename);
		
		int getNumMaps();
		
		IndexedImage *getImage();
		
		int type() const;
		
		enum {
			TYPE_UNKNOWN,
			TYPE_CAMPAIGN,
			TYPE_MULTIPLAYER_CAMPAIGN,
			TYPE_MAPFILE,
			TYPE_SAVEDGAME
		};
		
		const static int MAX_MAPS = 10;
	
	private:
		Building *getBuildings();
		Walker *getWalkers();
		int getMapsize();
		void skipBuildingSpecificBytes(Building *building);
		void placeBuildings(IndexedImage *img, Building *buildings,
			int mapsize);
		void placeBuilding(IndexedImage *img, int mapsize,
			int posX, int posY, int sizeX, int sizeY, int cid);
		void getTerrainColours(quint32 terrain, quint32 object,
			quint8 random, quint8 fertile, quint8 stone, int *c1, int *c2);
		
		int filetype;
		int numMaps;
		int retrievedMaps;
		int positions[MAX_MAPS];
		EmperorColours *colours;
};

#endif /* EMPERORFILE_H */
