/*
 *   Citybuilding Mappers - create minimaps from citybuilding game files
 *   Copyright (C) 2007, 2008  Bianca van Schaik
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef EMPERORMAPPER_H
#define EMPERORMAPPER_H

#include <QMainWindow>
#include <QString>

class QAction;
class QLabel;
class IndexedImage;
class AboutDialog;
class LicenceDialog;
class HelpDialog;
class EmperorThread;

class EmperorMapper : public QMainWindow {
	Q_OBJECT
	
	public:
		EmperorMapper();
		~EmperorMapper();
	
	private slots:
		void open();
		void save();
		void showMap(int id);
		void help();
		void licence();
		void about();
		
		void handleImages(const QList<IndexedImage *> &images);
		void handleError(int type);
		void threadFinished();
		
	private:
		void createActions();
		void createMenus();
		void loadFile(const QString &name);
		void setTitle(const QString &filename = QString());
		
		static const int MAX_MAPS = 10;
		
		QAction *openAction;
		QAction *saveAction;
		QAction *exitAction;
		QAction *helpAction;
		QAction *licenceAction;
		QAction *aboutAction;
		QAction *showActions[MAX_MAPS];
		QMenu *showMenu;
		AboutDialog *aboutDialog;
		LicenceDialog *licenceDialog;
		HelpDialog *helpDialog;
		QLabel *imageLabel;
		QList<IndexedImage *> images;
		QString filename;
		int numMaps;
		int currentMap;
		QString appname;
		EmperorThread *thread;
};

#endif /* EMPERORMAPPER_H */
