/*
 *   Citybuilding Mappers - create minimaps from citybuilding game files
 *   Copyright (C) 2007, 2008  Bianca van Schaik
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#include "emperorthread.h"
#include "emperorfile.h"

EmperorThread::EmperorThread(const QString &filename) {
	this->filename = filename;
}

void EmperorThread::run() {
	EmperorFile file(filename);
	QList<IndexedImage *> images;
	
	int numMaps = file.getNumMaps();
	if (numMaps > 0) {
		for (int i = 0; i < numMaps; i++) {
			images.append(file.getImage());
			if (images[i] == NULL) {
				// Delete the already retrieved maps
				for (int j = 0; j < i; j++) {
					delete images[j];
					images[j] = NULL;
				}
				// Notify thread owner of the error
				emit error(ERROR_CANTLOAD);
				return;
			}
		}
	} else if (file.type() == EmperorFile::TYPE_MULTIPLAYER_CAMPAIGN) {
		emit error(ERROR_MULTIPLAYER);
		return;
	} else {
		emit error(ERROR_CANTLOAD);
		return;
	}
	
	emit imagesDone(images);
}
