/*
 *   Citybuilding Mappers - create minimaps from citybuilding game files
 *   Copyright (C) 2007, 2008  Bianca van Schaik
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef GAMEFILE_H
#define GAMEFILE_H

#include <QIODevice>
#include "grid.h"

class GameFile {
	public:
		GameFile(const QString &file, bool compressed = false);
		~GameFile();
	
	protected:
		Grid<quint8> *readByteGrid();
		Grid<quint16> *readShortGrid();
		Grid<quint32> *readIntGrid();
		
		Grid<quint8> *readCompressedByteGrid();
		Grid<quint16> *readCompressedShortGrid();
		Grid<quint32> *readCompressedIntGrid();
		
		void skipBytes(int bytes);
		void skipCompressed();
		
		quint8 readByte();
		quint16 readShort();
		quint32 readInt();
		
		void getDiamondBitmapCoordinates(int x, int y, int mapsize,
			int *x_out, int *y_out);
		void getBitmapCoordinates(int x, int y, int mapsize,
			int *x_out, int *y_out);
		
		bool searchPattern(const quint8 pattern[], int length);
		
		QIODevice *in;
		int MAX_MAPSIZE;
		int MAX_WALKERS;
		int MAX_BUILDINGS;
		bool ok;
};

#endif /* GAMEFILE_H */
