/*
 *   Citybuilding Mappers - create minimaps from citybuilding game files
 *   Copyright (C) 2007, 2008  Bianca van Schaik
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#include "indexedimage.h"

IndexedImage::IndexedImage(int width, int height)
	: QImage(width, height, QImage::Format_Indexed8)
{
	// Initialise hash with base colour (black)
	colours.insert(0, 0);
	setNumColors(1);
	setColor(0, 0xff000000);
}

void IndexedImage::setIndexedPixel(int x, int y, uint argb) {
	// Check bounds
	if (x < 0 || y < 0 || x >= width() || y >= height()) {
		return;
	}
	
	if (colours.contains(argb)) {
		// Colour known, just paint
		setPixel(x, y, colours[argb]);
	} else {
		// Colour doesn't exist yet, create it
		uint index = colours.size();
		//qDebug("Color %x unknown, inserting at index %d", argb, index);
		
		// Increase size of palette and insert the new colour
		setNumColors(index+1);
		colours.insert(argb, index);
		setColor(index, 0xff000000 | argb);
		setPixel(x, y, index);
	}
}
