/*
 *   Citybuilding Mappers - create minimaps from citybuilding game files
 *   Copyright (C) 2007, 2008  Bianca van Schaik
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef PHARAOHFILE_H
#define PHARAOHFILE_H

#include <QString>

#include "gamefile.h"
#include "grid.h"
#include "pharaohcolours.h"

class IndexedImage;

typedef struct {
	unsigned short type;
	unsigned short x;
	unsigned short y;
} Walker;

typedef struct {
	unsigned short type;
	unsigned short x;
	unsigned short y;
	unsigned char size;
	unsigned char rotation;
} Building;

class PharaohFile : public GameFile {
	public:
		PharaohFile(const QString &filename);
		
		IndexedImage *getImage();
	
	private:
		void placeBuildings(IndexedImage *img, Building *buildings,
			 Grid<quint32> *terrain, Grid<quint8> *edges, int mapsize);
		void placeBuilding(IndexedImage *img, Grid<quint8> *edges,
			int mapsize, int posX, int posY,
			int sizeX, int sizeY, int c1, int c2);
		void getBuildingColours(quint32 building, quint8 edge,
			quint8 edge_right, quint8 edge_below, int *c1, int *c2);
		void getTerrainColours(quint32 terrain, quint8 random, int *c1, int *c2);
		Grid<quint8> *getRandomData();
		Walker *getWalkers();
		Building *getBuildings();
		int getMapsize();
		
		PharaohColours *colours;
};

#endif /* PHARAOHFILE_H */
