/*
 *   Citybuilding Mappers - create minimaps from citybuilding game files
 *   Copyright (C) 2007, 2008  Bianca van Schaik
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef ZEUSFILE_H
#define ZEUSFILE_H

#include "gamefile.h"
#include "grid.h"
#include "zeuscolours.h"

#include <QString>

class IndexedImage;

typedef struct {
	unsigned short type;
	unsigned short x;
	unsigned short y;
} Walker;

typedef struct {
	unsigned short type;
	unsigned short x;
	unsigned short y;
	unsigned char size;
	unsigned char rotation;
} Building;

class ZeusFile : public GameFile {
	public:
		static const int MAX_MAPS = 5; // parent city + 4 colonies
		
		ZeusFile(const QString &filename);
		
		/**
		* Returns the number of maps in this file. Call this function
		* before attempting to get any images from this map using
		* getImage();
		*/
		int getNumMaps();
		
		/**
		* Returns the next image available. Throws an exception if the
		* image can't be loaded for whatever reason.
		* NOTE: call getNumMaps() before calling this function
		*/
		IndexedImage *getImage();
		
		/**
		* Returns whether this file is an adventure or not. Call
		* *after* calling getImages();
		*/
		bool isAdventure();
		
	private:
		void placeBuildings(IndexedImage *img, Building *buildings,
			Grid<quint8> *edges, int mapsize, bool is_poseidon);
		void placeBuilding(IndexedImage *img, Grid<quint8> *edges,
			int mapsize, int posX, int posY,
			int sizeX, int sizeY, int c1, int c2, bool reverse);
		void getTerrainColours(quint32 terrain, quint8 random,
			quint8 meadow, quint8 scrub, quint8 t_marble, int *c1, int *c2);
		Walker *getWalkers();
		Building *getBuildings();
		int getMapsize();
		
		enum { TYPE_ADVENTURE, TYPE_MAPFILE, TYPE_SAVEDGAME };
		
		int filetype;
		int numMaps;
		int retrievedMaps;
		int positions[MAX_MAPS];
		ZeusColours *colours;
};

#endif /* ZEUSFILE_H */
