/*
 *   Citybuilding Mappers - create minimaps from citybuilding game files
 *   Copyright (C) 2007, 2008  Bianca van Schaik
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef ZLIBFILE_H
#define ZLIBFILE_H

#include <QIODevice>
#include <QFile>
#include <QBuffer>
#include <QString>
#include <QVarLengthArray>

class ZlibFile : public QIODevice {
	public:
		ZlibFile(const QString &filename);
		~ZlibFile();
		
		//bool atEnd() const;
		qint64 bytesAvailable() const;
		void close();
		bool isSequential() const;
		bool open(QIODevice::OpenMode mode);
		bool reset();
		bool seek(qint64 pos);
		qint64 size() const;
		bool multiPart() const;
		int numParts() const;
		bool selectPart(int part);
		
	protected:
		qint64 readData(char * data, qint64 maxSize);
		qint64 writeData(const char * data, qint64 maxSize);
		
	private:
		bool seekToBlock(int blockNumber);
		bool readBlock(int blockNumber = -1);
		void prefetchBlockPositions();
		quint32 getBlockLength();
		quint32 readInt();
		void setError(const QString &message);
		
		QFile *input;
		QBuffer buffer;
		QVarLengthArray<qint64> blockPositions;
		QVarLengthArray<quint32> partPositions;
		bool isMultiPart;
		int currentBlock;
		int currentPart;
		int maxBlocks;
		int maxParts;
		qint64 maxPosition;
		qint64 filesize;
		static const int blocksize = 0x8000;
};

#endif /* ZLIBFILE_H */
